@@ -2,9 +2,9 @@
 package DBIx::SearchBuilder;
 
 use strict;
+use warnings;
 
-use vars qw($VERSION);
-$VERSION = "1.45_01";
+our $VERSION = "1.45_02";
 
 use Clone qw();
 use Encode qw();
@@ -150,7 +150,6 @@ sub CleanSlate {
 	_close_parens
     group_by
     columns
-    criteria_count
     );
 
     #we have no limit statements. DoSearch won't work.
