@@ -1,49 +1,35 @@
 # $Header: /home/jesse/DBIx-SearchBuilder/history/SearchBuilder/Handle/Oracle.pm,v 1.14 2002/01/28 06:11:37 jesse Exp $
 
 package DBIx::SearchBuilder::Handle::Oracle;
-use DBIx::SearchBuilder::Handle;
-@ISA = qw(DBIx::SearchBuilder::Handle);
-
-use vars qw($VERSION @ISA $DBIHandle $DEBUG);
 
 use strict;
+use warnings;
 
+use base qw/DBIx::SearchBuilder::Handle/;
+
+use DBD::Oracle qw(:ora_types);
+         
 =head1 NAME
 
-  DBIx::SearchBuilder::Handle::Oracle -- an oracle specific Handle object
+  DBIx::SearchBuilder::Handle::Oracle - An oracle specific Handle object
 
 =head1 SYNOPSIS
 
 
 =head1 DESCRIPTION
 
-=head1 AUTHOR
+This module provides a subclass of DBIx::SearchBuilder::Handle that 
+compensates for some of the idiosyncrasies of Oracle.
 
-Jesse Vincent, jesse@fsck.com
-
-=head1 SEE ALSO
-
-perl(1), DBIx::SearchBuilder
+=head1 METHODS
 
 =cut
 
 
-sub new  {
-      my $proto = shift;
-      my $class = ref($proto) || $proto;
-      my $self  = {};
-      bless ($self, $class);
-      return ($self);
-}
-
-
-# {{{ sub Connect 
-
 =head2 Connect PARAMHASH: Driver, Database, Host, User, Password
 
 Takes a paramhash and connects to your DBI datasource. 
 
-
 =cut
 
 sub Connect  {
@@ -53,23 +39,20 @@ sub Connect  {
 	       Database => undef,
 	       User => undef,
 	       Password => undef, 
-           SID => undef,
-           Host => undef,
+	       SID => undef,
+	       Host => undef,
 	       @_);
   
-    $self->SUPER::Connect(%args);
-   
+    my $rv = $self->SUPER::Connect(%args);
     
     $self->dbh->{LongTruncOk}=1;
     $self->dbh->{LongReadLen}=8000;
     
     $self->SimpleQuery("ALTER SESSION set NLS_DATE_FORMAT = 'YYYY-MM-DD HH24:MI:SS'");
     
-    return ($DBIHandle); 
+    return ($rv); 
 }
-# }}}
 
-# {{{ sub Insert
 
 =head2 Insert
 
@@ -134,9 +117,7 @@ sub Insert  {
     return( $self->{'id'}); #Add Succeded. return the id
   }
 
-# }}}
 
-# {{{ BuildDSN
 
 =head2  BuildDSN PARAMHASH
 
@@ -173,9 +154,7 @@ sub BuildDSN {
   $self->{'dsn'}= $dsn;
 }
 
-# }}}
 
-# {{{ KnowsBLOBs      
 
 =head2 KnowsBLOBs     
 
@@ -189,9 +168,7 @@ sub KnowsBLOBs {
     return(undef);
 }
 
-# }}}
 
-# {{{ BLOBParams 
 
 =head2 BLOBParams FIELD_NAME FIELD_TYPE
 
@@ -206,12 +183,11 @@ sub BLOBParams {
     my $field = shift;
     #my $type = shift;
     # Don't assign to key 'value' as it is defined later.
-    return ( { ora_field => $field, ora_type => 112 });    
+    return ( { ora_field => $field, ora_type => ORA_CLOB,
+});    
 }
 
-# }}}
 
-# {{{ ApplyLimits
 
 =head2 ApplyLimits STATEMENTREF ROWS_PER_PAGE FIRST_ROW
 
@@ -257,33 +233,38 @@ sub ApplyLimits {
     }
 }
 
-# }}}
 
-# {{{ DistinctQuery
 
 =head2 DistinctQuery STATEMENTREF
 
 takes an incomplete SQL SELECT statement and massages it to return a DISTINCT result set.
 
-
 =cut
 
 sub DistinctQuery {
     my $self = shift;
     my $statementref = shift;
-    my $table = shift;
+    my $sb = shift;
+    my $table = $sb->Table;
 
-    # Wrapper select query in a subselect as Oracle doesn't allow
+    # Wrapp select query in a subselect as Oracle doesn't allow
     # DISTINCT against CLOB/BLOB column types.
-    $$statementref = "SELECT main.* FROM ( SELECT DISTINCT main.id FROM $$statementref ) distinctquery, $table main WHERE (main.id = distinctquery.id) ";
-
+    # Joop van de Wege: Thats correct but ORDER_BY column not in main doesn't need GROUP_BY
+    # so drop the group_by lines and add the order_by part but without the min()
+    if ($sb->_OrderClause =~ /(?<!main)\./) {
+        my $order = $sb->_OrderClause;
+        $$statementref = "SELECT main.* FROM ( SELECT main.id FROM $$statementref $order ) distinctquery,"
+            ." $table main WHERE (main.id = distinctquery.id)";
+    } else {
+        $$statementref = "SELECT main.* FROM ( SELECT DISTINCT main.id FROM $$statementref ) distinctquery,"
+            ." $table main WHERE (main.id = distinctquery.id) ";
+        $$statementref .= $sb->_GroupClause;
+        $$statementref .= $sb->_OrderClause;
+    }
 }
 
-# }}}
 
 
-# {{{ BinarySafeBLOBs
-
 =head2 BinarySafeBLOBs
 
 Return undef, as Oracle doesn't support binary-safe CLOBS
@@ -296,6 +277,17 @@ sub BinarySafeBLOBs {
     return(undef);
 }
 
-# }}}
 
 1;
+
+__END__
+
+=head1 AUTHOR
+
+Jesse Vincent, jesse@fsck.com
+
+=head1 SEE ALSO
+
+perl(1), DBIx::SearchBuilder
+
+=cut
