@@ -4,7 +4,7 @@ use warnings;
 
 # WARNING --- This is still development code.  It is experimental.
 
-our $VERSION = '$Version$';
+our $VERSION = '0';
 
 # This could inherit from DBIx::SearchBuilder, but there are _a lot_
 # of things in DBIx::SearchBuilder that we don't want, like Limit and
@@ -14,7 +14,7 @@ our $VERSION = '$Version$';
 
 =head1 NAME
 
-DBIx::Searchbuilder::Union - Deal with multiple SearchBuilder result sets as one
+DBIx::SearchBuilder::Union - Deal with multiple SearchBuilder result sets as one
 
 =head1 SYNOPSIS
 
@@ -106,8 +106,9 @@ sub Next {
   my $self=shift;
 
   return undef unless defined  $self->{data}[ $self->{curp} ];
-
+    
   my $cur =  $self->{data}[ $self->{curp} ];
+  $cur->_DoSearch(); # force the search, instead of doing a count.
   if ( $cur->_ItemsCounter == $cur->Count ) {
 	# move to the next element
 	$self->{curp}++;
